<template>
    <div class="TiltModelBox">
        <div id="sdkContainer"> </div>
    </div>
</template>

<script>
import mapData from '@/assets/js/mapSdk/mapData';
export default {
    name: 'tiltModel',
    data() {
        return {
            earthCtrl: null,
            Cesium: null,
            Viewer: null,
            serveType: null,
            model: null,
        }
    },
    mounted() {
        this.initMap();
    },
    methods: {
        async initMap() {
            this.earthCtrl = new SmartEarth.EarthCtrl('sdkContainer', {
                // 隐藏默认底图
                defaultImagery: false,
                // 隐藏logo
                printLog: false,
                StaticFileBaseUrl: '/CimSDK/',
            });
            // 初始化Viewer
            this.Viewer = this.earthCtrl.viewer;
            //设置地球颜色
            this.Viewer.scene.globe.baseColor = SmartEarth.Cesium.Color.fromCssColorString('#A9A9A9');
            const terrain = config.terrain;
            if (terrain.isUrl) {
                const terrainProvider = await SmartEarth.Cesium.CesiumTerrainProvider.fromUrl(terrain.isUrl, {
                    requestWaterMask: true,
                    requestVertexNormals: true,
                });

                this.Viewer.terrainProvider = terrainProvider;
            }
            this.addImageLayer();
            this.add3DTilesetsLayer(config.domTilesets.url);
        },
        add3DTilesetsLayer(url) {
            if (this.model) {
                this.model.deleteObject()
            }
            console.log(url);
            this.model = this.earthCtrl.factory.create3DTilesets({
                url: url,
            });
            //等待模型加载完毕飞往该模型
            this.model.item.readyPromise.then(() => {
                this.flyto()
            })
        },
        flyto() {
            const options = {
                duration: 2,
                offset: new SmartEarth.Cesium.HeadingPitchRange(1.0, -0.3, 1000)
            };
            this.earthCtrl.userScene.flyTo(this.model.item, options);
        },
        addImageLayer() {
            const baseLayer = mapData.baseLayer;
            // 添加天地图底图
            this.addLayer({
                serveType: 'tdMap',
                url: baseLayer.sUrl + baseLayer.imgLayer + baseLayer.lUrl,
            });
            // 添加天地图标注
            this.addLayer({
                serveType: 'tdMap',
                url: baseLayer.sUrl + baseLayer.cvaLayer + baseLayer.lUrl,
            });
            // 初始化视角
            this.setdefaultPerspective(mapData.defaultPerspective);
        },
        setdefaultPerspective(res) {
            this.earthCtrl.camera.jumpTo({
                destination: {
                    x: res.x,
                    y: res.y,
                    z: res.z,
                },
            });
        },
        addLayer(res) {
            this.serveType = res.serveType;
            switch (this.serveType) {
                case 'tdMap':
                    this.addTdLayer(res);
                    break;

            }
        },
        addTdLayer(res) {
            const url = res.url + config.tdToken;
            this.Viewer.imageryLayers.addImageryProvider(
                new SmartEarth.Cesium.UrlTemplateImageryProvider({
                    url: url,
                })
            );
        },
    }
}
</script>

<style lang="scss" scoped>
.TiltModelBox {
    width: calc(100% - 20px);
    height: calc(100% - 20px);
    position: absolute;
    margin: 10px;
    border-radius: 5px;
}
</style>